#
# Copyright (c) 2020-2024 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

set(CMAKE_MODULE_PATH "${CMAKE_CURRENT_SOURCE_DIR}/cmake/Modules")
find_package(jeffpc)
find_package(ncursesw REQUIRED)

include(FindPkgConfig)
pkg_check_modules(GPS REQUIRED libgps)
pkg_check_modules(HAMLIB REQUIRED hamlib)

include(CheckCSourceCompiles)

check_c_source_compiles("
#include <sys/socket.h>
int main() { return AF_PACKET; }
" HLOG_HAVE_AF_PACKET)

set(CMAKE_REQUIRED_INCLUDES "${HAMLIB_INCLUDE_DIRS}")

check_c_source_compiles("
#include <hamlib/config.h>
int main() { return 0; }
" HLOG_HAVE_HAMLIB_CONFIG_H)

check_c_source_compiles("
#include <hamlib/rig.h>
int main() { return RIG_EDEPRECATED; }
" HLOG_HAVE_RIG_EDEPRECATED)

check_c_source_compiles("
#include <hamlib/rig.h>
int main() { return RIG_ESECURITY; }
" HLOG_HAVE_RIG_ESECURITY)

check_c_source_compiles("
#include <hamlib/rig.h>
int main() { return RIG_EPOWER; }
" HLOG_HAVE_RIG_EPOWER)

check_c_source_compiles("
#include <hamlib/rig.h>
int main() { return RIG_EEND; }
" HLOG_HAVE_RIG_EEND)

configure_file("${CMAKE_CURRENT_SOURCE_DIR}/common/include/hlog/config.h.in"
	"${CMAKE_CURRENT_BINARY_DIR}/common/include/hlog/config.h")
