#
# Copyright (c) 2021,2023 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

include(FindLua)

if(LUA_FOUND AND
   (LUA_VERSION_MAJOR EQUAL 5) AND (LUA_VERSION_MINOR GREATER_EQUAL 3))
	find_program(LUA_COMPILER
		     NAMES luac${LUA_VERSION_MAJOR}${LUA_VERSION_MINOR}
		     	   luac${LUA_VERSION_MAJOR}.${LUA_VERSION_MINOR}
		     REQUIRED)
elseif(LUA_FOUND)
	message(FATAL_ERROR "Lua 5.3 or newer required, "
		"${LUA_VERSION_STRING} found")
else()
	message(FATAL_ERROR "Lua 5.3 or newer required")
endif()

# compile a .lua file into .luac
macro(lua_compile srcdir src dst)
	get_filename_component(dstdir "${dst}" DIRECTORY)

	add_custom_command(
		OUTPUT "${dst}"
		COMMAND rm -f "${dst}"
		COMMAND mkdir -p "${dstdir}"
		COMMAND ${LUA_COMPILER} -o "${dst}" "${src}"
		WORKING_DIRECTORY "${srcdir}"
		DEPENDS "${srcdir}/${src}"
	)
endmacro()
