/*
 * Copyright (c) 2020-2021,2024 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __INDEX_H
#define __INDEX_H

#include <hlog/qso.h>

struct index_stat {
	uint64_t band;
	uint64_t count;
	struct str *mode;
};

struct index_iter_ctx {
	uint64_t gen;
	struct index_stat *out;
	void *tree;
	void *link;
	bool asc;
};

extern int index_init(int data_dir);

extern uint64_t index_current_generation(void);

extern int index_get(const struct xuuid *uuid, struct qso *qso);
extern int index_save(struct qso *qso);

extern void index_counts(size_t *qsos_r);

extern struct qso *index_iter_history_start(struct index_iter_ctx *ctx, bool asc);
extern struct qso *index_iter_history_next(struct index_iter_ctx *ctx);
extern struct qso *index_iter_call_history_start(struct str *callstr,
						 struct index_iter_ctx *ctx,
						 bool asc);
extern struct qso *index_iter_call_history_next(struct index_iter_ctx *ctx);

extern void index_iter_call_stats_start(struct str *callstr,
					struct index_iter_ctx *ctx,
					struct index_stat *out);
extern bool index_iter_call_stats_next(struct index_iter_ctx *ctx);

#endif
