/*
 * Copyright (c) 2021-2022,2024 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __CONTEST_H
#define __CONTEST_H

#include <hlog/qso.h>
#include <hlog-lua/xlua.h>

#include "../common/recent.h"
#include "../common/ui.h"
#include "../common/xform.h"

struct contest_params {
	const char *name;
	uint32_t year;
};


extern int contest_init(const struct contest_params *contest_params,
			struct qso **template_r);
extern int contest_run(lua_State *L, struct xfield_def *wfields, size_t nwfields);
extern void contest_cleanup(void);

/*
 * interactive forms
 */
extern struct xform work; /* current QSO contest exchange */
extern struct xform current; /* current QSO in full */
extern struct recent recent_work_list; /* current contact history */
extern struct recent recent_list; /* all history */

/*
 * interactive form UI
 */
extern void ui_work_dispatch(lua_State *L, int ch, struct qso **qso);
extern void ui_current_dispatch(lua_State *L, int ch, struct qso **qso);

/*
 * contact handling
 */
extern int init_contact(lua_State *L, struct qso **qso, char *error,
			size_t errlen);
extern int save_qso_and_update_index(struct qso *qso, const char *source);

/*
 * callout box
 */
extern int callout_init(int height, int width, int row, int col);
extern void callout_destroy(void);
extern void callout_set(const char *str);

/*
 * message window
 */
enum msg_src {
	MSG_SYS, /* system message, intercepted cmn_err */
	MSG_GEO, /* location related messages */
	MSG_RIG, /* rig related messages */
	MSG_QSO, /* qso related messages */
	MSG_SCRIPT, /* contest script related messages */
};

extern int msg_init(void); /* allocate only */
extern void msg_free(void); /* free only */
extern void msg_start(void); /* start redirecting cmn_err */
extern void msg_stop(void); /* stop redirecting cmn_err & dump out all msgs */
extern void msg_print(enum msg_src src, enum errlevel level,
		      const char *fmt, ...);
extern void msg_get_msgs(bool (*cb)(enum msg_src src, enum errlevel level,
				    const struct time *ts, const char *msg,
				    void *private),
			 void *private);

/*
 * contest lua lib
 */
extern int contest_lualib_init(lua_State *L,
			       const struct contest_params *params);

#endif
