#!/bin/sh
#
# Copyright (c) 2020-2023 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

set -x

if [ $# -ne 1 ] ; then
	echo "Usage: $0 <path>" >&2
	exit 1
fi

DIR="$1"

if [ -d "$DIR" ] ; then
	echo "Error: '$DIR' already seems to exist" >&2
	exit 1
fi

mkdir "$DIR"
mkdir "$DIR/data"
mkdir "$DIR/qso"
mkdir "$DIR/tmp"

cat > "$DIR/config.lua" <<DONE
local function fill_template(qso, mode)
	-- The 'mode' argument conveys what executable invoked this
	-- function.  "normal" indicates that we were called by 'hlog',
	-- while values beginning with "contest" indicate 'hlog-contest'.

	qso.tx.station_call = "WX1YZ" -- de station call sign
	qso.tx.grid = "FN42" -- tx grid locator
	qso.tx.power = 1500 -- tx power in W
	qso.tx.mode = "SSB" -- tx mode
end

return {
	-- called once on startup to initialize a 'template' qso
	fill_template = fill_template,
}
DONE

curl https://pota.app/all_parks_ext.csv > "$DIR/data/pota_parks.csv"
curl https://mapping.sota.org.uk/summitslist.csv > "$DIR/data/sota_summits.csv"
curl https://www.country-files.com/bigcty/cty.csv > "$DIR/data/cty.csv"
