/*
 * Copyright (c) 2021-2024 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#include <jeffpc/error.h>

#include <hlog/config.h>

#include "hamlib-impl.h"

#ifdef HLOG_HAVE_HAMLIB_CONFIG_H
#include <hamlib/config.h>
#endif

/*
 * Set the version to something small if it is missing.
 */
#ifndef ABI_VERSION_MAJOR
#define ABI_VERSION_MAJOR 0
#endif

#ifndef ABI_VERSION_MINOR
#define ABI_VERSION_MINOR 0
#endif

#ifndef ABI_VERSION_PATCH
#define ABI_VERSION_PATCH 0
#endif

#define MKVER(ma, mi, pa)	(((ma) << 16) | ((mi) << 8) | ((pa) << 0))

#define CURRENT	\
	MKVER(ABI_VERSION_MAJOR, ABI_VERSION_MINOR, ABI_VERSION_PATCH)

void hamlib_set_quirks(struct hrig *rig, uint32_t model)
{
	/* initialize all quirks as disabled */
	rig->quirks.no_txpower = false;

	if ((model == RIG_MODEL_NETRIGCTL) && (CURRENT <= MKVER(4, 3, 1))) {
		rig->quirks.no_txpower = true;
		cmn_err(CE_WARN, "Hamlib 4.3.1 and older has buggy netrigctl");
		cmn_err(CE_WARN, "Disabling power announcements");
	}

	if ((model == RIG_MODEL_KX2) && (CURRENT <= MKVER(4, 5, 5))) {
		rig->quirks.no_txpower = true;
		cmn_err(CE_WARN, "Hamlib 4.5.5 and older has buggy KX2 backend");
		cmn_err(CE_WARN, "Disabling power announcements");
	}
}
