/*
 * Copyright (c) 2021-2023 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __RPC_HAMLIB_H
#define __RPC_HAMLIB_H

#include <hlog-rpc/rig-mode.h>

struct hrig;

struct hrig_state {
	uint64_t tx_freq;
	uint64_t rx_freq;
	uint32_t power;
	enum hrig_mode tx_mode;
	enum hrig_mode rx_mode;
	bool split;
	bool ptt; /* true == transmitting, false = receiving */
};

extern struct hrig *hamlib_alloc(uint32_t model, const char *dev);
extern void hamlib_free(struct hrig *rig);

extern int hamlib_open(struct hrig *rig);
extern int hamlib_close(struct hrig *rig);

extern int hamlib_get_state(struct hrig *rig, struct hrig_state *state);
extern int hamlib_get_mode(struct hrig *rig, enum hrig_mode *mode);
extern int hamlib_get_ptt(struct hrig *rig, bool *on);
extern int hamlib_get_freq(struct hrig *rig, uint64_t *freq);

extern int hamlib_set_mode(struct hrig *rig, enum hrig_mode mode, bool rx_if_split);
extern int hamlib_set_ptt(struct hrig *rig, bool on);
extern int hamlib_set_freq(struct hrig *rig, uint64_t freq, bool rx_if_split);

#endif
