/*
 * Copyright (c) 2020-2021,2023 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#include <hlog/time.h>
#include "xlua_impl.h"
#include "wrapper.h"

/* no actual ref counting */
static inline void time_putref(struct time *time)
{
}

static int xlua_time_index(lua_State *L);
static int xlua_time_tostring(lua_State *L);

static const luaL_Reg __time_fxns[] = {
	{ "__index", xlua_time_index },
	{ "__tostring", xlua_time_tostring },
	{ NULL, NULL },
};

WRAP_C_DATA(time, struct time, time_putref, __time_fxns)

/* handle a time[key], where table is -2 and key is -1 [-2,+1,e] */
static int xlua_time_index(lua_State *L)
{
	struct time *time;
	const char *name;

	time = xlua_time_getptr(L, -2, NULL);
	name = luaL_checkstring(L, -1);

	if (!strcmp(name, "year")) {
		if (time->have & TIME_PART_DATE)
			lua_pushinteger(L, time->year);
		else
			lua_pushnil(L);
	} else if (!strcmp(name, "month")) {
		if (time->have & TIME_PART_DATE)
			lua_pushinteger(L, time->month);
		else
			lua_pushnil(L);
	} else if (!strcmp(name, "day")) {
		if (time->have & TIME_PART_DATE)
			lua_pushinteger(L, time->day);
		else
			lua_pushnil(L);
	} else if (!strcmp(name, "hour")) {
		if (time->have & TIME_PART_TIME_HM)
			lua_pushinteger(L, time->hour);
		else
			lua_pushnil(L);
	} else if (!strcmp(name, "min")) {
		if (time->have & TIME_PART_TIME_HM)
			lua_pushinteger(L, time->min);
		else
			lua_pushnil(L);
	} else if (!strcmp(name, "sec")) {
		if (time->have & TIME_PART_TIME_S)
			lua_pushinteger(L, time->sec);
		else
			lua_pushnil(L);
	} else if (!strcmp(name, "unix")) {
		int64_t val;

		if (time_unix(time, &val))
			lua_pushinteger(L, val);
		else
			lua_pushnil(L);
	} else {
		luaL_error(L, "unknown field name '%s'", name);
	}

	return 1;
}

/* handle a tostring(time), where table is -1 [-1,+1,e] */
static int xlua_time_tostring(lua_State *L)
{
	struct time *time;
	char str[21];

	time = xlua_time_getptr(L, -1, NULL);

	if (time_snprint_iso8601(str, sizeof(str), time))
		lua_pushstring(L, str);
	else
		lua_pushstring(L, "<no time>");

	return 1;
}
